==> dl.php?src=linea21_1_4.zip: linea21/news/quickbox.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage news
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!HaveRight('news')) ReloadIndex('admin');
////////////

$qbx_module=_t('menu','news');

if ($todo == 'add') {
  $result=$sql_object->DBSelect($req_quickbox_add);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['news_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_crea').": ".$result[$i]['news_date_crea_display']." \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titleadd');
}

if ($todo == 'mod' || $todo == 'det') {
  $result=$sql_object->DBSelect($req_quickbox_mod);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['news_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','last_modify')." ".$result[$i]['news_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['news_date_crea_display'].") \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titlemod');
}
if ($todo == 'sup') {
  $result=$sql_object->DBSelect($req_quickbox_sup);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"#\" title=\""._t('divers','date_sup')." ".$result[$i]['news_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['news_date_crea_display'].") \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titlesup');
}
if ($todo == 'list') {
  $result=$sql_object->DBSelect($req_quickbox_list);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['news_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_publi')." ".$result[$i]['news_published_date_display']." - ("._t('divers','date_crea').": ".$result[$i]['news_date_crea_display'].") \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titlepubli');
}

echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
echo "</div>\n";
?>

==> dl.php?src=linea21_1_6.zip: linea21/news/quickbox.php <==
<?php
/**
 * @package linea21.modules
 * @subpackage news
 * @author linea21 <info@linea21.com>
 * @version $id SVN
 * @access public
 * @license http://opensource.org/licenses/gpl-3.0.html
 */

//////////// Check Inclusion de pages ////////////
if (!class_exists('auth')) {
  include_once("../lib/lib_common.php");
  ReloadIndex('admin');
}
////////////

//////////// Check Droits utilisateur ////////////
if (!$l21auth->hasRight('news')) ReloadIndex('admin');
////////////

$qbx_module=_t('menu','news');

if ($todo == 'add') {
  $result=$sql_object->DBSelect($req_quickbox_add);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['news_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_crea').": ".$result[$i]['news_date_crea_display']." \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titleadd');
}

if ($todo == 'mod' || $todo == 'det') {
  $result=$sql_object->DBSelect($req_quickbox_mod);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['news_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','last_modify')." ".$result[$i]['news_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['news_date_crea_display'].") \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titlemod');
}
if ($todo == 'sup') {
  $result=$sql_object->DBSelect($req_quickbox_sup);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"#\" title=\""._t('divers','date_sup')." ".$result[$i]['news_last_modify_display']." - ("._t('divers','date_crea').": ".$result[$i]['news_date_crea_display'].") \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titlesup');
}
if ($todo == 'list') {
  $result=$sql_object->DBSelect($req_quickbox_list);
  $qbx_liste='';
  $nb='';
  if($result==0) {
    $qbx_liste.="<li>"._t('divers','nodata')."</li>";
  } else {
    if(count($result)>=10) $nb=10; else $nb=count($result);
    for($i=0; $i<count($result); $i++) {
      $qbx_news_title=formatText(cutText($result[$i]['news_title'], 47), '2HTML');
      $qbx_liste.="<li><a href=\"index.php?id=". $result[$i]['news_id'] ."&amp;rub=".$rub."&amp;todo=det\" title=\""._t('divers','date_publi')." ".$result[$i]['news_published_date_display']." - ("._t('divers','date_crea').": ".$result[$i]['news_date_crea_display'].") \">". $qbx_news_title ."</a></li>\n";
    }
  }
  $qbx_h1=$nb._t('news','qb_titlepubli');
}

echo QuickBoxNow($qbx_module, $qbx_h1, $qbx_liste);
echo "</div>\n";
?>
